.. shopyo documentation master file, created by
   sphinx-quickstart on Sat Mar  7 23:26:49 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.


Welcome to Shopyo's docs!
=========================

Shopyo a fast, easy to use Point Of Sale system with
Open inventory management and Point of sales (powered by python) for small shops.


.. toctree::
   :maxdepth: 5

   setup
   contrib
   modules
   unittests
   views

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
